==> haskell-enclosed-exceptions-1.0.3-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: enclosed-exceptions
version: 1.0.3
id: enclosed-exceptions-1.0.3-BesPV6vBza327FnqgxcGea
key: enclosed-exceptions-1.0.3-BesPV6vBza327FnqgxcGea
license: MIT
maintainer: jmacristovao@gmail.com, michael@snoyman.com
author: Michael Snoyman, João Cristóvão
homepage: https://github.com/jcristovao/enclosed-exceptions
synopsis: Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>
category: Control
abi: 3ac148cfdfb0a59b138c550d56548eff
exposed: True
exposed-modules:
    Control.Exception.Enclosed
import-dirs: /usr/lib/ghc-8.6.5/site-local/enclosed-exceptions-1.0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/enclosed-exceptions-1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/enclosed-exceptions-1.0.3
hs-libraries: HSenclosed-exceptions-1.0.3-BesPV6vBza327FnqgxcGea
depends:
    base-4.12.0.0 deepseq-1.4.4.0
    lifted-base-0.2.3.12-DqYx7X0gMmM8Dg41WPLXSx
    monad-control-1.0.2.3-DXP4ByOEjHJ5rVzR8ITkTD transformers-0.5.6.2
    transformers-base-0.4.5.2-KiogS5KFFp4IwxvJXTI1QL
haddock-interfaces: /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock
haddock-html: /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-enclosed-exceptions-1.0.3-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: enclosed-exceptions
version: 1.0.3
id: enclosed-exceptions-1.0.3-7KzZTzFsZiHLFnuYxqHdK7
key: enclosed-exceptions-1.0.3-7KzZTzFsZiHLFnuYxqHdK7
license: MIT
maintainer: jmacristovao@gmail.com, michael@snoyman.com
author: Michael Snoyman, João Cristóvão
homepage: https://github.com/jcristovao/enclosed-exceptions
synopsis: Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>
category: Control
abi: c2901ed4d5572438e6e08fcda53b2927
exposed: True
exposed-modules:
    Control.Exception.Enclosed
import-dirs: /usr/lib/ghc-8.6.5/site-local/enclosed-exceptions-1.0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/enclosed-exceptions-1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/enclosed-exceptions-1.0.3
hs-libraries: HSenclosed-exceptions-1.0.3-7KzZTzFsZiHLFnuYxqHdK7
depends:
    base-4.12.0.0 deepseq-1.4.4.0
    lifted-base-0.2.3.12-AUNt1jz3AnFGEh5kQbukx0
    monad-control-1.0.2.3-FeYEsm8P5694VImLZDBXYS transformers-0.5.6.2
    transformers-base-0.4.5.2-HGTy7PtJMWjITFSZBfRdND
haddock-interfaces: /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock
haddock-html: /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
